
# Slot: exact mappings


A list of terms from different schemas or terminology systems that have identical meaning.

URI: [linkml:exact_mappings](https://w3id.org/linkml/exact_mappings)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Uriorcurie](Uriorcurie.md)

## Parents

 *  is_a: [mappings](mappings.md)

## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [EnumDefinition](EnumDefinition.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:exactMatch |

